﻿// System includes
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

// Honorbuddy includes
using Styx;
using Styx.Common;
using Styx.CommonBot;
using Styx.Helpers;
using Styx.WoWInternals;
using Styx.WoWInternals.WoWObjects;
using Styx.Plugins;
using Styx.Pathing;
using Styx.WoWInternals.World;
using SessionStats.GUI;
using SessionStats.Helpers;

namespace PluginSample
{
    public class SessionStats : HBPlugin
    {
        /// <summary>
        /// This is a standard variable declare as it grants access to player specific information
        /// </summary>
        public static LocalPlayer Me = StyxWoW.Me;

        private static GUI gui = null;
        

        /// <summary>
        /// Set up your variables as static so you can access them from the settings form.
        /// These are called within there respective overrides below as described in each.
        /// </summary>
        public static string PluginName = "SessionStats";
        public static string PluginAuthor = "Digit";
        public static Version PluginVersion = new Version(1, 0, 0, 0);
        public static string PluginSettingsButton = "-Settings-";

        /// <summary>
        /// The name that you would like the user to see in the list of plugins.
        /// </summary>
        public override string Name
        {
            get { return PluginName; }
        }

        
        /// <summary>
        /// You can use this parameter to set your company name, or your forum name.
        /// </summary>
        public override string Author
        {
            get { return PluginAuthor; }
        }

        /// <summary>
        /// The version of your plugin
        /// </summary>
        public override Version Version
        {
            get { return PluginVersion; }
        }

        /// <summary>
        /// The caption of the settings button in the plugin window.
        /// </summary>
        public override string ButtonText
        {
            get { return PluginSettingsButton; }
        }

        /// <summary>
        /// If you wish to have a settings button in the plugin window, set this to "true"; else return "false".
        /// </summary>
        public override bool WantButton
        {
            get
            {
                // Check if settings button string is set. If string length is greater than 0, then we want the button
                if (PluginSettingsButton.Length > 0)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        /// <summary>
        /// This function is called as soon as this assembly is loaded into memory, and thus a great place to initialize any events.
        /// </summary>
        public SessionStats()
        {
            BotEvents.OnBotStopped += BotEvents_OnBotStopped;
            BotEvents.OnBotStarted += BotEvents_OnBotStarted;
            BotEvents.OnBotChanged += BotEvents_OnBotChanged;
            BotEvents.OnBotStartRequested += BotEvents_OnBotStartRequested;
            BotEvents.OnBotStopRequested += BotEvents_OnBotStopRequested;
        
            gui = new GUI();
            
        }

        private void BotEvents_OnPulse(object sender, EventArgs e)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// This gets called shortly after the function using the same name as your plugin class is called.
        /// </summary>
        static public void Initialize()
        {
            
        }

        /// <summary>
        /// Honorbuddy core sends a Pulse event which occurs similar to a heartbeat. You can use this when you need to work with events as they happen to the player.
        /// </summary>
        public override void Pulse()
        {

        }

        /// <summary>
        /// When the user clicks on your "config" button
        /// </summary>
        public override void OnButtonPress()
        {
            gui.UpdateGUI();
            gui.ShowDialog();
            
        }

        /// <summary>
        /// Fires when the user enables your plugin (checks it)
        /// </summary>
        public override void OnEnable()
        {
            Logger.Log("Enabled()", PluginVersion);
            base.OnEnable();
        }

        /// <summary>
        /// Fires when the user disables your plugin (unchecks it)
        /// </summary>
        public override void OnDisable()
        {
            base.OnDisable();
        }

        /// <summary>
        /// This event is called if the user changes bot bases.
        /// </summary>
        /// <param name="args"></param>
        static void BotEvents_OnBotChanged(BotEvents.BotChangedEventArgs args)
        {

        }

        /// <summary>
        /// This event occurs after the user clicks start, but before everything has been initialized.
        /// </summary>
        /// <param name="args"></param>
        static void BotEvents_OnBotStartRequested(BotEvents.BotStartStopRequestEventArgs args)
        {
            
        }

        /// <summary>
        /// Fired after everything has been initialized and the bot is started.
        /// </summary>
        /// <param name="args"></param>
        static void BotEvents_OnBotStarted(EventArgs args)
        {
            gui.botStopWatch.Start();
        }

        /// <summary>
        /// Called when the user pushes stop, but before the bot has stopped
        /// </summary>
        /// <param name="args"></param>
        static void BotEvents_OnBotStopRequested(BotEvents.BotStartStopRequestEventArgs args)
        {

        }

        /// <summary>
        /// Called after the user pushes stop, and the bot has stopped.
        /// </summary>
        /// <param name="args"></param>
        static void BotEvents_OnBotStopped(EventArgs args)
        {
            gui.botStopWatch.Stop();
        }

    }
}
